import 'package:flutter/material.dart';

class NuntioTextField extends StatefulWidget {
  final String? label;
  final String? hint;
  final TextInputType? textInputType;
  final TextEditingController controller;
  final bool? obscureText;
  final TextInputAction? textInputAction;
  final Function(String)? onChanged;
  final IconData? prefix;
  final Brightness? brightness;
  final FocusNode? focusNode;
  final EdgeInsets? scrollPadding;
  final Iterable<String>? autofillHints;
  final EdgeInsets padding;
  final String? Function(String? val)? validator;

  NuntioTextField({
    this.padding = EdgeInsets.zero,
    required this.controller,
    this.label,
    this.hint,
    this.textInputType,
    this.obscureText,
    this.textInputAction,
    this.onChanged,
    this.prefix,
    this.brightness,
    this.focusNode,
    this.scrollPadding,
    this.autofillHints,
    this.validator,
  });

  @override
  State<NuntioTextField> createState() => _NuntioTextFieldState(
        focusNode: focusNode ?? FocusNode(),
      );
}

class _NuntioTextFieldState extends State<NuntioTextField> {
  final FocusNode focusNode;
  bool obscureText = true;

  _NuntioTextFieldState({
    required this.focusNode,
  });

  @override
  void initState() {
    obscureText = widget.obscureText ?? false;
    focusNode.addListener(() {
      if (focusNode.hasFocus) {
        setState(() {});
      } else {
        setState(() {});
      }
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: widget.padding,
      child: Column(
        children: [
          if (widget.label?.isNotEmpty == true)
            Padding(
              padding: const EdgeInsets.only(bottom: 5, left: 5),
              child: Align(
                alignment: Alignment.centerLeft,
                child: Text(
                  widget.label!,
                  style: Theme.of(context).textTheme.labelLarge,
                  textAlign: TextAlign.left,
                ),
              ),
            ),
          TextFormField(
            autocorrect: true,
            autofillHints: widget.autofillHints,
            focusNode: focusNode,
            validator: widget.validator,
            scrollPadding: widget.scrollPadding ?? EdgeInsets.only(bottom: 40),
            obscureText: obscureText,
            onTap: () {},
            cursorColor: Theme.of(context).primaryColor,
            decoration: InputDecoration(
              hintText: widget.hint,
              prefixIcon: Icon(
                widget.prefix,
                size: 22,
                color: focusNode.hasFocus
                    ? Theme.of(context).primaryColor
                    : Theme.of(context).dividerColor,
              ),
              suffixIcon: widget.obscureText == true
                  ? IconButton(
                      icon: Icon(
                        obscureText
                            ? Icons.remove_red_eye_outlined
                            : Icons.remove_red_eye_sharp,
                      ),
                      onPressed: () {
                        setState(() {
                          obscureText = !obscureText;
                        });
                      },
                      color: focusNode.hasFocus
                          ? Theme.of(context).primaryColor
                          : Theme.of(context).dividerColor,
                    )
                  : SizedBox(),
            ),
            textInputAction: widget.textInputAction,
            // Moves focus to next.
            controller: widget.controller,
            keyboardType: widget.textInputType,
            onChanged: widget.onChanged,
          ),
        ],
      ),
    );
  }
}
