import 'dart:io';
import "package:grpc/grpc.dart" show ChannelCredentials;
import 'dart:convert';

abstract class TransportCredentials {
  Future<ChannelCredentials> getTransportCredentials();
}

class CloudCredentials implements TransportCredentials {
  final Uri apiUrl;

  CloudCredentials({required this.apiUrl});

  bool onBadCertificate(cert, comment) {
    throw Exception("bad certificate");
  }

  @override
  Future<ChannelCredentials> getTransportCredentials() async {
    RawSecureSocket socket =
    await RawSecureSocket.connect(apiUrl.host, apiUrl.port);
    if (socket.peerCertificate == null) {
      throw Exception("peer certificate is null. Contact info@nuntio.io");
    }
    X509Certificate x509certificate = socket.peerCertificate!;
    return ChannelCredentials.secure(
      certificates: utf8.encode(x509certificate.pem),
      onBadCertificate: onBadCertificate,
      authority: apiUrl.host,
    );
  }
}
